Class: DaytonaToolboxApiClient::ChartElement

Inherits:
ApiModelBase show all
Defined in:
lib/daytona_toolbox_api_client/models/chart_element.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ChartElement

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/daytona_toolbox_api_client/models/chart_element.rb', line 116

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaToolboxApiClient::ChartElement` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaToolboxApiClient::ChartElement`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'angle')
    self.angle = attributes[:'angle']
  end

  if attributes.key?(:'first_quartile')
    self.first_quartile = attributes[:'first_quartile']
  end

  if attributes.key?(:'group')
    self.group = attributes[:'group']
  end

  if attributes.key?(:'label')
    self.label = attributes[:'label']
  end

  if attributes.key?(:'max')
    self.max = attributes[:'max']
  end

  if attributes.key?(:'median')
    self.median = attributes[:'median']
  end

  if attributes.key?(:'min')
    self.min = attributes[:'min']
  end

  if attributes.key?(:'outliers')
    if (value = attributes[:'outliers']).is_a?(Array)
      self.outliers = value
    end
  end

  if attributes.key?(:'png')
    self.png = attributes[:'png']
  end

  if attributes.key?(:'points')
    if (value = attributes[:'points']).is_a?(Array)
      self.points = value
    end
  end

  if attributes.key?(:'radius')
    self.radius = attributes[:'radius']
  end

  if attributes.key?(:'third_quartile')
    self.third_quartile = attributes[:'third_quartile']
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'value')
    self.value = attributes[:'value']
  end

  if attributes.key?(:'x_label')
    self.x_label = attributes[:'x_label']
  end

  if attributes.key?(:'y_label')
    self.y_label = attributes[:'y_label']
  end
end

Instance Attribute Details

#angleObject

Returns the value of attribute angle.



18
19
20
# File 'lib/daytona_toolbox_api_client/models/chart_element.rb', line 18

def angle
  @angle
end

#first_quartileObject

Returns the value of attribute first_quartile.



20
21
22
# File 'lib/daytona_toolbox_api_client/models/chart_element.rb', line 20

def first_quartile
  @first_quartile
end

#groupObject

Returns the value of attribute group.



22
23
24
# File 'lib/daytona_toolbox_api_client/models/chart_element.rb', line 22

def group
  @group
end

#labelObject

Returns the value of attribute label.



24
25
26
# File 'lib/daytona_toolbox_api_client/models/chart_element.rb', line 24

def label
  @label
end

#maxObject

Returns the value of attribute max.



26
27
28
# File 'lib/daytona_toolbox_api_client/models/chart_element.rb', line 26

def max
  @max
end

#medianObject

Returns the value of attribute median.



28
29
30
# File 'lib/daytona_toolbox_api_client/models/chart_element.rb', line 28

def median
  @median
end

#minObject

Returns the value of attribute min.



30
31
32
# File 'lib/daytona_toolbox_api_client/models/chart_element.rb', line 30

def min
  @min
end

#outliersObject

Returns the value of attribute outliers.



32
33
34
# File 'lib/daytona_toolbox_api_client/models/chart_element.rb', line 32

def outliers
  @outliers
end

#pngObject

Returns the value of attribute png.



34
35
36
# File 'lib/daytona_toolbox_api_client/models/chart_element.rb', line 34

def png
  @png
end

#pointsObject

Returns the value of attribute points.



36
37
38
# File 'lib/daytona_toolbox_api_client/models/chart_element.rb', line 36

def points
  @points
end

#radiusObject

Returns the value of attribute radius.



38
39
40
# File 'lib/daytona_toolbox_api_client/models/chart_element.rb', line 38

def radius
  @radius
end

#third_quartileObject

Returns the value of attribute third_quartile.



40
41
42
# File 'lib/daytona_toolbox_api_client/models/chart_element.rb', line 40

def third_quartile
  @third_quartile
end

#titleObject

Returns the value of attribute title.



42
43
44
# File 'lib/daytona_toolbox_api_client/models/chart_element.rb', line 42

def title
  @title
end

#typeObject

Returns the value of attribute type.



44
45
46
# File 'lib/daytona_toolbox_api_client/models/chart_element.rb', line 44

def type
  @type
end

#valueObject

Returns the value of attribute value.



46
47
48
# File 'lib/daytona_toolbox_api_client/models/chart_element.rb', line 46

def value
  @value
end

#x_labelObject

Returns the value of attribute x_label.



48
49
50
# File 'lib/daytona_toolbox_api_client/models/chart_element.rb', line 48

def x_label
  @x_label
end

#y_labelObject

Returns the value of attribute y_label.



50
51
52
# File 'lib/daytona_toolbox_api_client/models/chart_element.rb', line 50

def y_label
  @y_label
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



76
77
78
# File 'lib/daytona_toolbox_api_client/models/chart_element.rb', line 76

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



81
82
83
# File 'lib/daytona_toolbox_api_client/models/chart_element.rb', line 81

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/daytona_toolbox_api_client/models/chart_element.rb', line 53

def self.attribute_map
  {
    :'angle' => :'angle',
    :'first_quartile' => :'first_quartile',
    :'group' => :'group',
    :'label' => :'label',
    :'max' => :'max',
    :'median' => :'median',
    :'min' => :'min',
    :'outliers' => :'outliers',
    :'png' => :'png',
    :'points' => :'points',
    :'radius' => :'radius',
    :'third_quartile' => :'third_quartile',
    :'title' => :'title',
    :'type' => :'type',
    :'value' => :'value',
    :'x_label' => :'x_label',
    :'y_label' => :'y_label'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/daytona_toolbox_api_client/models/chart_element.rb', line 257

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



109
110
111
112
# File 'lib/daytona_toolbox_api_client/models/chart_element.rb', line 109

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/daytona_toolbox_api_client/models/chart_element.rb', line 86

def self.openapi_types
  {
    :'angle' => :'Float',
    :'first_quartile' => :'Float',
    :'group' => :'String',
    :'label' => :'String',
    :'max' => :'Float',
    :'median' => :'Float',
    :'min' => :'Float',
    :'outliers' => :'Array<Float>',
    :'png' => :'String',
    :'points' => :'Array<Array<Float>>',
    :'radius' => :'Float',
    :'third_quartile' => :'Float',
    :'title' => :'String',
    :'type' => :'String',
    :'value' => :'String',
    :'x_label' => :'String',
    :'y_label' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
# File 'lib/daytona_toolbox_api_client/models/chart_element.rb', line 220

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      angle == o.angle &&
      first_quartile == o.first_quartile &&
      group == o.group &&
      label == o.label &&
      max == o.max &&
      median == o.median &&
      min == o.min &&
      outliers == o.outliers &&
      png == o.png &&
      points == o.points &&
      radius == o.radius &&
      third_quartile == o.third_quartile &&
      title == o.title &&
      type == o.type &&
      value == o.value &&
      x_label == o.x_label &&
      y_label == o.y_label
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


244
245
246
# File 'lib/daytona_toolbox_api_client/models/chart_element.rb', line 244

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



250
251
252
# File 'lib/daytona_toolbox_api_client/models/chart_element.rb', line 250

def hash
  [angle, first_quartile, group, label, max, median, min, outliers, png, points, radius, third_quartile, title, type, value, x_label, y_label].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



205
206
207
208
209
# File 'lib/daytona_toolbox_api_client/models/chart_element.rb', line 205

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



279
280
281
282
283
284
285
286
287
288
289
290
291
# File 'lib/daytona_toolbox_api_client/models/chart_element.rb', line 279

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



213
214
215
216
# File 'lib/daytona_toolbox_api_client/models/chart_element.rb', line 213

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end