Class: DaytonaToolboxApiClient::CompletionItem
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- DaytonaToolboxApiClient::CompletionItem
- Defined in:
- lib/daytona_toolbox_api_client/models/completion_item.rb
Instance Attribute Summary collapse
-
#detail ⇒ Object
Returns the value of attribute detail.
-
#documentation ⇒ Object
Returns the value of attribute documentation.
-
#filter_text ⇒ Object
Returns the value of attribute filter_text.
-
#insert_text ⇒ Object
Returns the value of attribute insert_text.
-
#kind ⇒ Object
Returns the value of attribute kind.
-
#label ⇒ Object
Returns the value of attribute label.
-
#sort_text ⇒ Object
Returns the value of attribute sort_text.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CompletionItem
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CompletionItem
Initializes the object
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/daytona_toolbox_api_client/models/completion_item.rb', line 76 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaToolboxApiClient::CompletionItem` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaToolboxApiClient::CompletionItem`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'detail') self.detail = attributes[:'detail'] end if attributes.key?(:'documentation') self.documentation = attributes[:'documentation'] end if attributes.key?(:'filter_text') self.filter_text = attributes[:'filter_text'] end if attributes.key?(:'insert_text') self.insert_text = attributes[:'insert_text'] end if attributes.key?(:'kind') self.kind = attributes[:'kind'] end if attributes.key?(:'label') self.label = attributes[:'label'] else self.label = nil end if attributes.key?(:'sort_text') self.sort_text = attributes[:'sort_text'] end end |
Instance Attribute Details
#detail ⇒ Object
Returns the value of attribute detail.
18 19 20 |
# File 'lib/daytona_toolbox_api_client/models/completion_item.rb', line 18 def detail @detail end |
#documentation ⇒ Object
Returns the value of attribute documentation.
20 21 22 |
# File 'lib/daytona_toolbox_api_client/models/completion_item.rb', line 20 def documentation @documentation end |
#filter_text ⇒ Object
Returns the value of attribute filter_text.
22 23 24 |
# File 'lib/daytona_toolbox_api_client/models/completion_item.rb', line 22 def filter_text @filter_text end |
#insert_text ⇒ Object
Returns the value of attribute insert_text.
24 25 26 |
# File 'lib/daytona_toolbox_api_client/models/completion_item.rb', line 24 def insert_text @insert_text end |
#kind ⇒ Object
Returns the value of attribute kind.
26 27 28 |
# File 'lib/daytona_toolbox_api_client/models/completion_item.rb', line 26 def kind @kind end |
#label ⇒ Object
Returns the value of attribute label.
28 29 30 |
# File 'lib/daytona_toolbox_api_client/models/completion_item.rb', line 28 def label @label end |
#sort_text ⇒ Object
Returns the value of attribute sort_text.
30 31 32 |
# File 'lib/daytona_toolbox_api_client/models/completion_item.rb', line 30 def sort_text @sort_text end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
46 47 48 |
# File 'lib/daytona_toolbox_api_client/models/completion_item.rb', line 46 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
51 52 53 |
# File 'lib/daytona_toolbox_api_client/models/completion_item.rb', line 51 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
33 34 35 36 37 38 39 40 41 42 43 |
# File 'lib/daytona_toolbox_api_client/models/completion_item.rb', line 33 def self.attribute_map { :'detail' => :'detail', :'documentation' => :'documentation', :'filter_text' => :'filterText', :'insert_text' => :'insertText', :'kind' => :'kind', :'label' => :'label', :'sort_text' => :'sortText' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/daytona_toolbox_api_client/models/completion_item.rb', line 180 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
69 70 71 72 |
# File 'lib/daytona_toolbox_api_client/models/completion_item.rb', line 69 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/daytona_toolbox_api_client/models/completion_item.rb', line 56 def self.openapi_types { :'detail' => :'String', :'documentation' => :'Object', :'filter_text' => :'String', :'insert_text' => :'String', :'kind' => :'Integer', :'label' => :'String', :'sort_text' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/daytona_toolbox_api_client/models/completion_item.rb', line 153 def ==(o) return true if self.equal?(o) self.class == o.class && detail == o.detail && documentation == o.documentation && filter_text == o.filter_text && insert_text == o.insert_text && kind == o.kind && label == o.label && sort_text == o.sort_text end |
#eql?(o) ⇒ Boolean
167 168 169 |
# File 'lib/daytona_toolbox_api_client/models/completion_item.rb', line 167 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
173 174 175 |
# File 'lib/daytona_toolbox_api_client/models/completion_item.rb', line 173 def hash [detail, documentation, filter_text, insert_text, kind, label, sort_text].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
123 124 125 126 127 128 129 130 131 |
# File 'lib/daytona_toolbox_api_client/models/completion_item.rb', line 123 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @label.nil? invalid_properties.push('invalid value for "label", label cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
202 203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/daytona_toolbox_api_client/models/completion_item.rb', line 202 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
135 136 137 138 139 |
# File 'lib/daytona_toolbox_api_client/models/completion_item.rb', line 135 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @label.nil? true end |