Class: DaytonaToolboxApiClient::FindAccessibilityNodesRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/daytona_toolbox_api_client/models/find_accessibility_nodes_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ FindAccessibilityNodesRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/daytona_toolbox_api_client/models/find_accessibility_nodes_request.rb', line 77

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaToolboxApiClient::FindAccessibilityNodesRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaToolboxApiClient::FindAccessibilityNodesRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'limit')
    self.limit = attributes[:'limit']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'name_match')
    self.name_match = attributes[:'name_match']
  end

  if attributes.key?(:'pid')
    self.pid = attributes[:'pid']
  end

  if attributes.key?(:'role')
    self.role = attributes[:'role']
  end

  if attributes.key?(:'scope')
    self.scope = attributes[:'scope']
  end

  if attributes.key?(:'states')
    if (value = attributes[:'states']).is_a?(Array)
      self.states = value
    end
  end
end

Instance Attribute Details

#limitObject

Returns the value of attribute limit.



18
19
20
# File 'lib/daytona_toolbox_api_client/models/find_accessibility_nodes_request.rb', line 18

def limit
  @limit
end

#nameObject

Returns the value of attribute name.



20
21
22
# File 'lib/daytona_toolbox_api_client/models/find_accessibility_nodes_request.rb', line 20

def name
  @name
end

#name_matchObject

"exact" | "substring" | "regex"



23
24
25
# File 'lib/daytona_toolbox_api_client/models/find_accessibility_nodes_request.rb', line 23

def name_match
  @name_match
end

#pidObject

Returns the value of attribute pid.



25
26
27
# File 'lib/daytona_toolbox_api_client/models/find_accessibility_nodes_request.rb', line 25

def pid
  @pid
end

#roleObject

Returns the value of attribute role.



27
28
29
# File 'lib/daytona_toolbox_api_client/models/find_accessibility_nodes_request.rb', line 27

def role
  @role
end

#scopeObject

Returns the value of attribute scope.



29
30
31
# File 'lib/daytona_toolbox_api_client/models/find_accessibility_nodes_request.rb', line 29

def scope
  @scope
end

#statesObject

Returns the value of attribute states.



31
32
33
# File 'lib/daytona_toolbox_api_client/models/find_accessibility_nodes_request.rb', line 31

def states
  @states
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



47
48
49
# File 'lib/daytona_toolbox_api_client/models/find_accessibility_nodes_request.rb', line 47

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



52
53
54
# File 'lib/daytona_toolbox_api_client/models/find_accessibility_nodes_request.rb', line 52

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



34
35
36
37
38
39
40
41
42
43
44
# File 'lib/daytona_toolbox_api_client/models/find_accessibility_nodes_request.rb', line 34

def self.attribute_map
  {
    :'limit' => :'limit',
    :'name' => :'name',
    :'name_match' => :'nameMatch',
    :'pid' => :'pid',
    :'role' => :'role',
    :'scope' => :'scope',
    :'states' => :'states'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
# File 'lib/daytona_toolbox_api_client/models/find_accessibility_nodes_request.rb', line 166

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



70
71
72
73
# File 'lib/daytona_toolbox_api_client/models/find_accessibility_nodes_request.rb', line 70

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



57
58
59
60
61
62
63
64
65
66
67
# File 'lib/daytona_toolbox_api_client/models/find_accessibility_nodes_request.rb', line 57

def self.openapi_types
  {
    :'limit' => :'Integer',
    :'name' => :'String',
    :'name_match' => :'String',
    :'pid' => :'Integer',
    :'role' => :'String',
    :'scope' => :'String',
    :'states' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



139
140
141
142
143
144
145
146
147
148
149
# File 'lib/daytona_toolbox_api_client/models/find_accessibility_nodes_request.rb', line 139

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      limit == o.limit &&
      name == o.name &&
      name_match == o.name_match &&
      pid == o.pid &&
      role == o.role &&
      scope == o.scope &&
      states == o.states
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


153
154
155
# File 'lib/daytona_toolbox_api_client/models/find_accessibility_nodes_request.rb', line 153

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



159
160
161
# File 'lib/daytona_toolbox_api_client/models/find_accessibility_nodes_request.rb', line 159

def hash
  [limit, name, name_match, pid, role, scope, states].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



124
125
126
127
128
# File 'lib/daytona_toolbox_api_client/models/find_accessibility_nodes_request.rb', line 124

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



188
189
190
191
192
193
194
195
196
197
198
199
200
# File 'lib/daytona_toolbox_api_client/models/find_accessibility_nodes_request.rb', line 188

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



132
133
134
135
# File 'lib/daytona_toolbox_api_client/models/find_accessibility_nodes_request.rb', line 132

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end