Class: DaytonaToolboxApiClient::GitAddRemoteRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/daytona_toolbox_api_client/models/git_add_remote_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GitAddRemoteRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/daytona_toolbox_api_client/models/git_add_remote_request.rb', line 70

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaToolboxApiClient::GitAddRemoteRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaToolboxApiClient::GitAddRemoteRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'fetch')
    self.fetch = attributes[:'fetch']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'overwrite')
    self.overwrite = attributes[:'overwrite']
  end

  if attributes.key?(:'path')
    self.path = attributes[:'path']
  else
    self.path = nil
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  else
    self.url = nil
  end
end

Instance Attribute Details

#fetchObject

Fetch fetches from the remote immediately after adding it.



19
20
21
# File 'lib/daytona_toolbox_api_client/models/git_add_remote_request.rb', line 19

def fetch
  @fetch
end

#nameObject

Returns the value of attribute name.



21
22
23
# File 'lib/daytona_toolbox_api_client/models/git_add_remote_request.rb', line 21

def name
  @name
end

#overwriteObject

Overwrite replaces an existing remote with the same name.



24
25
26
# File 'lib/daytona_toolbox_api_client/models/git_add_remote_request.rb', line 24

def overwrite
  @overwrite
end

#pathObject

Returns the value of attribute path.



26
27
28
# File 'lib/daytona_toolbox_api_client/models/git_add_remote_request.rb', line 26

def path
  @path
end

#urlObject

Returns the value of attribute url.



28
29
30
# File 'lib/daytona_toolbox_api_client/models/git_add_remote_request.rb', line 28

def url
  @url
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



42
43
44
# File 'lib/daytona_toolbox_api_client/models/git_add_remote_request.rb', line 42

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



47
48
49
# File 'lib/daytona_toolbox_api_client/models/git_add_remote_request.rb', line 47

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
39
# File 'lib/daytona_toolbox_api_client/models/git_add_remote_request.rb', line 31

def self.attribute_map
  {
    :'fetch' => :'fetch',
    :'name' => :'name',
    :'overwrite' => :'overwrite',
    :'path' => :'path',
    :'url' => :'url'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/daytona_toolbox_api_client/models/git_add_remote_request.rb', line 198

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



63
64
65
66
# File 'lib/daytona_toolbox_api_client/models/git_add_remote_request.rb', line 63

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



52
53
54
55
56
57
58
59
60
# File 'lib/daytona_toolbox_api_client/models/git_add_remote_request.rb', line 52

def self.openapi_types
  {
    :'fetch' => :'Boolean',
    :'name' => :'String',
    :'overwrite' => :'Boolean',
    :'path' => :'String',
    :'url' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



173
174
175
176
177
178
179
180
181
# File 'lib/daytona_toolbox_api_client/models/git_add_remote_request.rb', line 173

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      fetch == o.fetch &&
      name == o.name &&
      overwrite == o.overwrite &&
      path == o.path &&
      url == o.url
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


185
186
187
# File 'lib/daytona_toolbox_api_client/models/git_add_remote_request.rb', line 185

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



191
192
193
# File 'lib/daytona_toolbox_api_client/models/git_add_remote_request.rb', line 191

def hash
  [fetch, name, overwrite, path, url].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/daytona_toolbox_api_client/models/git_add_remote_request.rb', line 113

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @path.nil?
    invalid_properties.push('invalid value for "path", path cannot be nil.')
  end

  if @url.nil?
    invalid_properties.push('invalid value for "url", url cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/daytona_toolbox_api_client/models/git_add_remote_request.rb', line 220

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



133
134
135
136
137
138
139
# File 'lib/daytona_toolbox_api_client/models/git_add_remote_request.rb', line 133

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @path.nil?
  return false if @url.nil?
  true
end