Class: DaytonaToolboxApiClient::GitCloneRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/daytona_toolbox_api_client/models/git_clone_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GitCloneRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
# File 'lib/daytona_toolbox_api_client/models/git_clone_request.rb', line 77

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaToolboxApiClient::GitCloneRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaToolboxApiClient::GitCloneRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'branch')
    self.branch = attributes[:'branch']
  end

  if attributes.key?(:'commit_id')
    self.commit_id = attributes[:'commit_id']
  end

  if attributes.key?(:'insecure_skip_tls')
    self.insecure_skip_tls = attributes[:'insecure_skip_tls']
  end

  if attributes.key?(:'password')
    self.password = attributes[:'password']
  end

  if attributes.key?(:'path')
    self.path = attributes[:'path']
  else
    self.path = nil
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  else
    self.url = nil
  end

  if attributes.key?(:'username')
    self.username = attributes[:'username']
  end
end

Instance Attribute Details

#branchObject

Returns the value of attribute branch.



18
19
20
# File 'lib/daytona_toolbox_api_client/models/git_clone_request.rb', line 18

def branch
  @branch
end

#commit_idObject

Returns the value of attribute commit_id.



20
21
22
# File 'lib/daytona_toolbox_api_client/models/git_clone_request.rb', line 20

def commit_id
  @commit_id
end

#insecure_skip_tlsObject

Skip TLS certificate verification for this clone. Defaults to false (verify). Set to true ONLY for trusted internal Git servers with self-signed or private-CA certs; credentials, if supplied, will be transmitted over an unverified TLS connection and are exposed to any MITM on the route.



23
24
25
# File 'lib/daytona_toolbox_api_client/models/git_clone_request.rb', line 23

def insecure_skip_tls
  @insecure_skip_tls
end

#passwordObject

Returns the value of attribute password.



25
26
27
# File 'lib/daytona_toolbox_api_client/models/git_clone_request.rb', line 25

def password
  @password
end

#pathObject

Returns the value of attribute path.



27
28
29
# File 'lib/daytona_toolbox_api_client/models/git_clone_request.rb', line 27

def path
  @path
end

#urlObject

Returns the value of attribute url.



29
30
31
# File 'lib/daytona_toolbox_api_client/models/git_clone_request.rb', line 29

def url
  @url
end

#usernameObject

Returns the value of attribute username.



31
32
33
# File 'lib/daytona_toolbox_api_client/models/git_clone_request.rb', line 31

def username
  @username
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



47
48
49
# File 'lib/daytona_toolbox_api_client/models/git_clone_request.rb', line 47

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



52
53
54
# File 'lib/daytona_toolbox_api_client/models/git_clone_request.rb', line 52

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



34
35
36
37
38
39
40
41
42
43
44
# File 'lib/daytona_toolbox_api_client/models/git_clone_request.rb', line 34

def self.attribute_map
  {
    :'branch' => :'branch',
    :'commit_id' => :'commit_id',
    :'insecure_skip_tls' => :'insecure_skip_tls',
    :'password' => :'password',
    :'path' => :'path',
    :'url' => :'url',
    :'username' => :'username'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/daytona_toolbox_api_client/models/git_clone_request.rb', line 198

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



70
71
72
73
# File 'lib/daytona_toolbox_api_client/models/git_clone_request.rb', line 70

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



57
58
59
60
61
62
63
64
65
66
67
# File 'lib/daytona_toolbox_api_client/models/git_clone_request.rb', line 57

def self.openapi_types
  {
    :'branch' => :'String',
    :'commit_id' => :'String',
    :'insecure_skip_tls' => :'Boolean',
    :'password' => :'String',
    :'path' => :'String',
    :'url' => :'String',
    :'username' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



171
172
173
174
175
176
177
178
179
180
181
# File 'lib/daytona_toolbox_api_client/models/git_clone_request.rb', line 171

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      branch == o.branch &&
      commit_id == o.commit_id &&
      insecure_skip_tls == o.insecure_skip_tls &&
      password == o.password &&
      path == o.path &&
      url == o.url &&
      username == o.username
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


185
186
187
# File 'lib/daytona_toolbox_api_client/models/git_clone_request.rb', line 185

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



191
192
193
# File 'lib/daytona_toolbox_api_client/models/git_clone_request.rb', line 191

def hash
  [branch, commit_id, insecure_skip_tls, password, path, url, username].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/daytona_toolbox_api_client/models/git_clone_request.rb', line 126

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @path.nil?
    invalid_properties.push('invalid value for "path", path cannot be nil.')
  end

  if @url.nil?
    invalid_properties.push('invalid value for "url", url cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



220
221
222
223
224
225
226
227
228
229
230
231
232
# File 'lib/daytona_toolbox_api_client/models/git_clone_request.rb', line 220

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



142
143
144
145
146
147
# File 'lib/daytona_toolbox_api_client/models/git_clone_request.rb', line 142

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @path.nil?
  return false if @url.nil?
  true
end