Class: DaytonaToolboxApiClient::GitPushRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/daytona_toolbox_api_client/models/git_push_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GitPushRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
# File 'lib/daytona_toolbox_api_client/models/git_push_request.rb', line 75

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaToolboxApiClient::GitPushRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaToolboxApiClient::GitPushRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'branch')
    self.branch = attributes[:'branch']
  end

  if attributes.key?(:'password')
    self.password = attributes[:'password']
  end

  if attributes.key?(:'path')
    self.path = attributes[:'path']
  else
    self.path = nil
  end

  if attributes.key?(:'remote')
    self.remote = attributes[:'remote']
  end

  if attributes.key?(:'set_upstream')
    self.set_upstream = attributes[:'set_upstream']
  end

  if attributes.key?(:'username')
    self.username = attributes[:'username']
  end
end

Instance Attribute Details

#branchObject

Branch to push (defaults to the current branch).



19
20
21
# File 'lib/daytona_toolbox_api_client/models/git_push_request.rb', line 19

def branch
  @branch
end

#passwordObject

Returns the value of attribute password.



21
22
23
# File 'lib/daytona_toolbox_api_client/models/git_push_request.rb', line 21

def password
  @password
end

#pathObject

Returns the value of attribute path.



23
24
25
# File 'lib/daytona_toolbox_api_client/models/git_push_request.rb', line 23

def path
  @path
end

#remoteObject

Remote to push to (defaults to "origin").



26
27
28
# File 'lib/daytona_toolbox_api_client/models/git_push_request.rb', line 26

def remote
  @remote
end

#set_upstreamObject

SetUpstream records the pushed branch as the upstream tracking branch.



29
30
31
# File 'lib/daytona_toolbox_api_client/models/git_push_request.rb', line 29

def set_upstream
  @set_upstream
end

#usernameObject

Returns the value of attribute username.



31
32
33
# File 'lib/daytona_toolbox_api_client/models/git_push_request.rb', line 31

def username
  @username
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



46
47
48
# File 'lib/daytona_toolbox_api_client/models/git_push_request.rb', line 46

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



51
52
53
# File 'lib/daytona_toolbox_api_client/models/git_push_request.rb', line 51

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



34
35
36
37
38
39
40
41
42
43
# File 'lib/daytona_toolbox_api_client/models/git_push_request.rb', line 34

def self.attribute_map
  {
    :'branch' => :'branch',
    :'password' => :'password',
    :'path' => :'path',
    :'remote' => :'remote',
    :'set_upstream' => :'set_upstream',
    :'username' => :'username'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'lib/daytona_toolbox_api_client/models/git_push_request.rb', line 174

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



68
69
70
71
# File 'lib/daytona_toolbox_api_client/models/git_push_request.rb', line 68

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



56
57
58
59
60
61
62
63
64
65
# File 'lib/daytona_toolbox_api_client/models/git_push_request.rb', line 56

def self.openapi_types
  {
    :'branch' => :'String',
    :'password' => :'String',
    :'path' => :'String',
    :'remote' => :'String',
    :'set_upstream' => :'Boolean',
    :'username' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



148
149
150
151
152
153
154
155
156
157
# File 'lib/daytona_toolbox_api_client/models/git_push_request.rb', line 148

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      branch == o.branch &&
      password == o.password &&
      path == o.path &&
      remote == o.remote &&
      set_upstream == o.set_upstream &&
      username == o.username
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


161
162
163
# File 'lib/daytona_toolbox_api_client/models/git_push_request.rb', line 161

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



167
168
169
# File 'lib/daytona_toolbox_api_client/models/git_push_request.rb', line 167

def hash
  [branch, password, path, remote, set_upstream, username].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



118
119
120
121
122
123
124
125
126
# File 'lib/daytona_toolbox_api_client/models/git_push_request.rb', line 118

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @path.nil?
    invalid_properties.push('invalid value for "path", path cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/daytona_toolbox_api_client/models/git_push_request.rb', line 196

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



130
131
132
133
134
# File 'lib/daytona_toolbox_api_client/models/git_push_request.rb', line 130

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @path.nil?
  true
end