Class: DaytonaToolboxApiClient::GitRestoreRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- DaytonaToolboxApiClient::GitRestoreRequest
- Defined in:
- lib/daytona_toolbox_api_client/models/git_restore_request.rb
Instance Attribute Summary collapse
-
#files ⇒ Object
Returns the value of attribute files.
-
#path ⇒ Object
Returns the value of attribute path.
-
#source ⇒ Object
Source restores file contents from the given revision instead of the index.
-
#staged ⇒ Object
Staged restores the staging index for the given files.
-
#worktree ⇒ Object
Worktree restores the working tree for the given files.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GitRestoreRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GitRestoreRequest
Initializes the object
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/daytona_toolbox_api_client/models/git_restore_request.rb', line 71 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaToolboxApiClient::GitRestoreRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaToolboxApiClient::GitRestoreRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'files') if (value = attributes[:'files']).is_a?(Array) self.files = value end else self.files = nil end if attributes.key?(:'path') self.path = attributes[:'path'] else self.path = nil end if attributes.key?(:'source') self.source = attributes[:'source'] end if attributes.key?(:'staged') self.staged = attributes[:'staged'] end if attributes.key?(:'worktree') self.worktree = attributes[:'worktree'] end end |
Instance Attribute Details
#files ⇒ Object
Returns the value of attribute files.
18 19 20 |
# File 'lib/daytona_toolbox_api_client/models/git_restore_request.rb', line 18 def files @files end |
#path ⇒ Object
Returns the value of attribute path.
20 21 22 |
# File 'lib/daytona_toolbox_api_client/models/git_restore_request.rb', line 20 def path @path end |
#source ⇒ Object
Source restores file contents from the given revision instead of the index.
23 24 25 |
# File 'lib/daytona_toolbox_api_client/models/git_restore_request.rb', line 23 def source @source end |
#staged ⇒ Object
Staged restores the staging index for the given files.
26 27 28 |
# File 'lib/daytona_toolbox_api_client/models/git_restore_request.rb', line 26 def staged @staged end |
#worktree ⇒ Object
Worktree restores the working tree for the given files.
29 30 31 |
# File 'lib/daytona_toolbox_api_client/models/git_restore_request.rb', line 29 def worktree @worktree end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
43 44 45 |
# File 'lib/daytona_toolbox_api_client/models/git_restore_request.rb', line 43 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
48 49 50 |
# File 'lib/daytona_toolbox_api_client/models/git_restore_request.rb', line 48 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
32 33 34 35 36 37 38 39 40 |
# File 'lib/daytona_toolbox_api_client/models/git_restore_request.rb', line 32 def self.attribute_map { :'files' => :'files', :'path' => :'path', :'source' => :'source', :'staged' => :'staged', :'worktree' => :'worktree' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/daytona_toolbox_api_client/models/git_restore_request.rb', line 184 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
64 65 66 67 |
# File 'lib/daytona_toolbox_api_client/models/git_restore_request.rb', line 64 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
53 54 55 56 57 58 59 60 61 |
# File 'lib/daytona_toolbox_api_client/models/git_restore_request.rb', line 53 def self.openapi_types { :'files' => :'Array<String>', :'path' => :'String', :'source' => :'String', :'staged' => :'Boolean', :'worktree' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
159 160 161 162 163 164 165 166 167 |
# File 'lib/daytona_toolbox_api_client/models/git_restore_request.rb', line 159 def ==(o) return true if self.equal?(o) self.class == o.class && files == o.files && path == o.path && source == o.source && staged == o.staged && worktree == o.worktree end |
#eql?(o) ⇒ Boolean
171 172 173 |
# File 'lib/daytona_toolbox_api_client/models/git_restore_request.rb', line 171 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
177 178 179 |
# File 'lib/daytona_toolbox_api_client/models/git_restore_request.rb', line 177 def hash [files, path, source, staged, worktree].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/daytona_toolbox_api_client/models/git_restore_request.rb', line 114 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @files.nil? invalid_properties.push('invalid value for "files", files cannot be nil.') end if @path.nil? invalid_properties.push('invalid value for "path", path cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/daytona_toolbox_api_client/models/git_restore_request.rb', line 206 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
130 131 132 133 134 135 |
# File 'lib/daytona_toolbox_api_client/models/git_restore_request.rb', line 130 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @files.nil? return false if @path.nil? true end |