Class: DaytonaToolboxApiClient::GitStatus

Inherits:
ApiModelBase show all
Defined in:
lib/daytona_toolbox_api_client/models/git_status.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GitStatus

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/daytona_toolbox_api_client/models/git_status.rb', line 68

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaToolboxApiClient::GitStatus` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaToolboxApiClient::GitStatus`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'ahead')
    self.ahead = attributes[:'ahead']
  end

  if attributes.key?(:'behind')
    self.behind = attributes[:'behind']
  end

  if attributes.key?(:'branch_published')
    self.branch_published = attributes[:'branch_published']
  end

  if attributes.key?(:'current_branch')
    self.current_branch = attributes[:'current_branch']
  else
    self.current_branch = nil
  end

  if attributes.key?(:'file_status')
    if (value = attributes[:'file_status']).is_a?(Array)
      self.file_status = value
    end
  else
    self.file_status = nil
  end
end

Instance Attribute Details

#aheadObject

Returns the value of attribute ahead.



18
19
20
# File 'lib/daytona_toolbox_api_client/models/git_status.rb', line 18

def ahead
  @ahead
end

#behindObject

Returns the value of attribute behind.



20
21
22
# File 'lib/daytona_toolbox_api_client/models/git_status.rb', line 20

def behind
  @behind
end

#branch_publishedObject

Returns the value of attribute branch_published.



22
23
24
# File 'lib/daytona_toolbox_api_client/models/git_status.rb', line 22

def branch_published
  @branch_published
end

#current_branchObject

Returns the value of attribute current_branch.



24
25
26
# File 'lib/daytona_toolbox_api_client/models/git_status.rb', line 24

def current_branch
  @current_branch
end

#file_statusObject

Returns the value of attribute file_status.



26
27
28
# File 'lib/daytona_toolbox_api_client/models/git_status.rb', line 26

def file_status
  @file_status
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



40
41
42
# File 'lib/daytona_toolbox_api_client/models/git_status.rb', line 40

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



45
46
47
# File 'lib/daytona_toolbox_api_client/models/git_status.rb', line 45

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



29
30
31
32
33
34
35
36
37
# File 'lib/daytona_toolbox_api_client/models/git_status.rb', line 29

def self.attribute_map
  {
    :'ahead' => :'ahead',
    :'behind' => :'behind',
    :'branch_published' => :'branchPublished',
    :'current_branch' => :'currentBranch',
    :'file_status' => :'fileStatus'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/daytona_toolbox_api_client/models/git_status.rb', line 181

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



61
62
63
64
# File 'lib/daytona_toolbox_api_client/models/git_status.rb', line 61

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



50
51
52
53
54
55
56
57
58
# File 'lib/daytona_toolbox_api_client/models/git_status.rb', line 50

def self.openapi_types
  {
    :'ahead' => :'Integer',
    :'behind' => :'Integer',
    :'branch_published' => :'Boolean',
    :'current_branch' => :'String',
    :'file_status' => :'Array<FileStatus>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



156
157
158
159
160
161
162
163
164
# File 'lib/daytona_toolbox_api_client/models/git_status.rb', line 156

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      ahead == o.ahead &&
      behind == o.behind &&
      branch_published == o.branch_published &&
      current_branch == o.current_branch &&
      file_status == o.file_status
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


168
169
170
# File 'lib/daytona_toolbox_api_client/models/git_status.rb', line 168

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



174
175
176
# File 'lib/daytona_toolbox_api_client/models/git_status.rb', line 174

def hash
  [ahead, behind, branch_published, current_branch, file_status].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/daytona_toolbox_api_client/models/git_status.rb', line 111

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @current_branch.nil?
    invalid_properties.push('invalid value for "current_branch", current_branch cannot be nil.')
  end

  if @file_status.nil?
    invalid_properties.push('invalid value for "file_status", file_status cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/daytona_toolbox_api_client/models/git_status.rb', line 203

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



127
128
129
130
131
132
# File 'lib/daytona_toolbox_api_client/models/git_status.rb', line 127

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @current_branch.nil?
  return false if @file_status.nil?
  true
end