Class: DaytonaToolboxApiClient::InfoApi
- Inherits:
-
Object
- Object
- DaytonaToolboxApiClient::InfoApi
- Defined in:
- lib/daytona_toolbox_api_client/api/info_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_user_home_dir(opts = {}) ⇒ UserHomeDirResponse
Get user home directory Get the current user home directory path.
-
#get_user_home_dir_with_http_info(opts = {}) ⇒ Array<(UserHomeDirResponse, Integer, Hash)>
Get user home directory Get the current user home directory path.
-
#get_version(opts = {}) ⇒ Hash<String, String>
Get version Get the current daemon version.
-
#get_version_with_http_info(opts = {}) ⇒ Array<(Hash<String, String>, Integer, Hash)>
Get version Get the current daemon version.
-
#get_work_dir(opts = {}) ⇒ WorkDirResponse
Get working directory Get the current working directory path.
-
#get_work_dir_with_http_info(opts = {}) ⇒ Array<(WorkDirResponse, Integer, Hash)>
Get working directory Get the current working directory path.
-
#initialize(api_client = ApiClient.default) ⇒ InfoApi
constructor
A new instance of InfoApi.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/daytona_toolbox_api_client/api/info_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_user_home_dir(opts = {}) ⇒ UserHomeDirResponse
Get user home directory Get the current user home directory path.
26 27 28 29 |
# File 'lib/daytona_toolbox_api_client/api/info_api.rb', line 26 def get_user_home_dir(opts = {}) data, _status_code, _headers = get_user_home_dir_with_http_info(opts) data end |
#get_user_home_dir_with_http_info(opts = {}) ⇒ Array<(UserHomeDirResponse, Integer, Hash)>
Get user home directory Get the current user home directory path.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/daytona_toolbox_api_client/api/info_api.rb', line 35 def get_user_home_dir_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: InfoApi.get_user_home_dir ...' end # resource path local_var_path = '/user-home-dir' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'UserHomeDirResponse' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"InfoApi.get_user_home_dir", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: InfoApi#get_user_home_dir\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_version(opts = {}) ⇒ Hash<String, String>
Get version Get the current daemon version
83 84 85 86 |
# File 'lib/daytona_toolbox_api_client/api/info_api.rb', line 83 def get_version(opts = {}) data, _status_code, _headers = get_version_with_http_info(opts) data end |
#get_version_with_http_info(opts = {}) ⇒ Array<(Hash<String, String>, Integer, Hash)>
Get version Get the current daemon version
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/daytona_toolbox_api_client/api/info_api.rb', line 92 def get_version_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: InfoApi.get_version ...' end # resource path local_var_path = '/version' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Hash<String, String>' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"InfoApi.get_version", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: InfoApi#get_version\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_work_dir(opts = {}) ⇒ WorkDirResponse
Get working directory Get the current working directory path. This is default directory used for running commands.
140 141 142 143 |
# File 'lib/daytona_toolbox_api_client/api/info_api.rb', line 140 def get_work_dir(opts = {}) data, _status_code, _headers = get_work_dir_with_http_info(opts) data end |
#get_work_dir_with_http_info(opts = {}) ⇒ Array<(WorkDirResponse, Integer, Hash)>
Get working directory Get the current working directory path. This is default directory used for running commands.
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/daytona_toolbox_api_client/api/info_api.rb', line 149 def get_work_dir_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: InfoApi.get_work_dir ...' end # resource path local_var_path = '/work-dir' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'WorkDirResponse' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"InfoApi.get_work_dir", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: InfoApi#get_work_dir\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |