Class: DaytonaToolboxApiClient::PortApi
- Inherits:
-
Object
- Object
- DaytonaToolboxApiClient::PortApi
- Defined in:
- lib/daytona_toolbox_api_client/api/port_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_ports(opts = {}) ⇒ PortList
Get active ports Get a list of all currently active ports.
-
#get_ports_with_http_info(opts = {}) ⇒ Array<(PortList, Integer, Hash)>
Get active ports Get a list of all currently active ports.
-
#initialize(api_client = ApiClient.default) ⇒ PortApi
constructor
A new instance of PortApi.
-
#is_port_in_use(port, opts = {}) ⇒ IsPortInUseResponse
Check if port is in use Check if a specific port is currently in use.
-
#is_port_in_use_with_http_info(port, opts = {}) ⇒ Array<(IsPortInUseResponse, Integer, Hash)>
Check if port is in use Check if a specific port is currently in use.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/daytona_toolbox_api_client/api/port_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_ports(opts = {}) ⇒ PortList
Get active ports Get a list of all currently active ports
26 27 28 29 |
# File 'lib/daytona_toolbox_api_client/api/port_api.rb', line 26 def get_ports(opts = {}) data, _status_code, _headers = get_ports_with_http_info(opts) data end |
#get_ports_with_http_info(opts = {}) ⇒ Array<(PortList, Integer, Hash)>
Get active ports Get a list of all currently active ports
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/daytona_toolbox_api_client/api/port_api.rb', line 35 def get_ports_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PortApi.get_ports ...' end # resource path local_var_path = '/port' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'PortList' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"PortApi.get_ports", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PortApi#get_ports\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#is_port_in_use(port, opts = {}) ⇒ IsPortInUseResponse
Check if port is in use Check if a specific port is currently in use
84 85 86 87 |
# File 'lib/daytona_toolbox_api_client/api/port_api.rb', line 84 def is_port_in_use(port, opts = {}) data, _status_code, _headers = is_port_in_use_with_http_info(port, opts) data end |
#is_port_in_use_with_http_info(port, opts = {}) ⇒ Array<(IsPortInUseResponse, Integer, Hash)>
Check if port is in use Check if a specific port is currently in use
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/daytona_toolbox_api_client/api/port_api.rb', line 94 def is_port_in_use_with_http_info(port, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PortApi.is_port_in_use ...' end # verify the required parameter 'port' is set if @api_client.config.client_side_validation && port.nil? fail ArgumentError, "Missing the required parameter 'port' when calling PortApi.is_port_in_use" end # resource path local_var_path = '/port/{port}/in-use'.sub('{' + 'port' + '}', CGI.escape(port.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'IsPortInUseResponse' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"PortApi.is_port_in_use", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PortApi#is_port_in_use\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |