Class: DaytonaToolboxApiClient::PtyResizeRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- DaytonaToolboxApiClient::PtyResizeRequest
- Defined in:
- lib/daytona_toolbox_api_client/models/pty_resize_request.rb
Instance Attribute Summary collapse
-
#cols ⇒ Object
Returns the value of attribute cols.
-
#rows ⇒ Object
Returns the value of attribute rows.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PtyResizeRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PtyResizeRequest
Initializes the object
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/daytona_toolbox_api_client/models/pty_resize_request.rb', line 56 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaToolboxApiClient::PtyResizeRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaToolboxApiClient::PtyResizeRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'cols') self.cols = attributes[:'cols'] else self.cols = nil end if attributes.key?(:'rows') self.rows = attributes[:'rows'] else self.rows = nil end end |
Instance Attribute Details
#cols ⇒ Object
Returns the value of attribute cols.
18 19 20 |
# File 'lib/daytona_toolbox_api_client/models/pty_resize_request.rb', line 18 def cols @cols end |
#rows ⇒ Object
Returns the value of attribute rows.
20 21 22 |
# File 'lib/daytona_toolbox_api_client/models/pty_resize_request.rb', line 20 def rows @rows end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
31 32 33 |
# File 'lib/daytona_toolbox_api_client/models/pty_resize_request.rb', line 31 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
36 37 38 |
# File 'lib/daytona_toolbox_api_client/models/pty_resize_request.rb', line 36 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
23 24 25 26 27 28 |
# File 'lib/daytona_toolbox_api_client/models/pty_resize_request.rb', line 23 def self.attribute_map { :'cols' => :'cols', :'rows' => :'rows' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/daytona_toolbox_api_client/models/pty_resize_request.rb', line 188 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
49 50 51 52 |
# File 'lib/daytona_toolbox_api_client/models/pty_resize_request.rb', line 49 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
41 42 43 44 45 46 |
# File 'lib/daytona_toolbox_api_client/models/pty_resize_request.rb', line 41 def self.openapi_types { :'cols' => :'Integer', :'rows' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
166 167 168 169 170 171 |
# File 'lib/daytona_toolbox_api_client/models/pty_resize_request.rb', line 166 def ==(o) return true if self.equal?(o) self.class == o.class && cols == o.cols && rows == o.rows end |
#eql?(o) ⇒ Boolean
175 176 177 |
# File 'lib/daytona_toolbox_api_client/models/pty_resize_request.rb', line 175 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
181 182 183 |
# File 'lib/daytona_toolbox_api_client/models/pty_resize_request.rb', line 181 def hash [cols, rows].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/daytona_toolbox_api_client/models/pty_resize_request.rb', line 85 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @cols.nil? invalid_properties.push('invalid value for "cols", cols cannot be nil.') end if @cols > 1000 invalid_properties.push('invalid value for "cols", must be smaller than or equal to 1000.') end if @cols < 1 invalid_properties.push('invalid value for "cols", must be greater than or equal to 1.') end if @rows.nil? invalid_properties.push('invalid value for "rows", rows cannot be nil.') end if @rows > 1000 invalid_properties.push('invalid value for "rows", must be smaller than or equal to 1000.') end if @rows < 1 invalid_properties.push('invalid value for "rows", must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
210 211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/daytona_toolbox_api_client/models/pty_resize_request.rb', line 210 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
117 118 119 120 121 122 123 124 125 126 |
# File 'lib/daytona_toolbox_api_client/models/pty_resize_request.rb', line 117 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @cols.nil? return false if @cols > 1000 return false if @cols < 1 return false if @rows.nil? return false if @rows > 1000 return false if @rows < 1 true end |