Class: DaytonaToolboxApiClient::PtySessionInfo
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- DaytonaToolboxApiClient::PtySessionInfo
- Defined in:
- lib/daytona_toolbox_api_client/models/pty_session_info.rb
Instance Attribute Summary collapse
-
#active ⇒ Object
Returns the value of attribute active.
-
#cols ⇒ Object
Returns the value of attribute cols.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#cwd ⇒ Object
Returns the value of attribute cwd.
-
#envs ⇒ Object
Returns the value of attribute envs.
-
#id ⇒ Object
Returns the value of attribute id.
-
#lazy_start ⇒ Object
Whether this session uses lazy start.
-
#rows ⇒ Object
Returns the value of attribute rows.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PtySessionInfo
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PtySessionInfo
Initializes the object
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/daytona_toolbox_api_client/models/pty_session_info.rb', line 81 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaToolboxApiClient::PtySessionInfo` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaToolboxApiClient::PtySessionInfo`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'active') self.active = attributes[:'active'] else self.active = nil end if attributes.key?(:'cols') self.cols = attributes[:'cols'] else self.cols = nil end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'cwd') self.cwd = attributes[:'cwd'] else self.cwd = nil end if attributes.key?(:'envs') if (value = attributes[:'envs']).is_a?(Hash) self.envs = value end else self.envs = nil end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'lazy_start') self.lazy_start = attributes[:'lazy_start'] else self.lazy_start = nil end if attributes.key?(:'rows') self.rows = attributes[:'rows'] else self.rows = nil end end |
Instance Attribute Details
#active ⇒ Object
Returns the value of attribute active.
18 19 20 |
# File 'lib/daytona_toolbox_api_client/models/pty_session_info.rb', line 18 def active @active end |
#cols ⇒ Object
Returns the value of attribute cols.
20 21 22 |
# File 'lib/daytona_toolbox_api_client/models/pty_session_info.rb', line 20 def cols @cols end |
#created_at ⇒ Object
Returns the value of attribute created_at.
22 23 24 |
# File 'lib/daytona_toolbox_api_client/models/pty_session_info.rb', line 22 def created_at @created_at end |
#cwd ⇒ Object
Returns the value of attribute cwd.
24 25 26 |
# File 'lib/daytona_toolbox_api_client/models/pty_session_info.rb', line 24 def cwd @cwd end |
#envs ⇒ Object
Returns the value of attribute envs.
26 27 28 |
# File 'lib/daytona_toolbox_api_client/models/pty_session_info.rb', line 26 def envs @envs end |
#id ⇒ Object
Returns the value of attribute id.
28 29 30 |
# File 'lib/daytona_toolbox_api_client/models/pty_session_info.rb', line 28 def id @id end |
#lazy_start ⇒ Object
Whether this session uses lazy start
31 32 33 |
# File 'lib/daytona_toolbox_api_client/models/pty_session_info.rb', line 31 def lazy_start @lazy_start end |
#rows ⇒ Object
Returns the value of attribute rows.
33 34 35 |
# File 'lib/daytona_toolbox_api_client/models/pty_session_info.rb', line 33 def rows @rows end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
50 51 52 |
# File 'lib/daytona_toolbox_api_client/models/pty_session_info.rb', line 50 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
55 56 57 |
# File 'lib/daytona_toolbox_api_client/models/pty_session_info.rb', line 55 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
36 37 38 39 40 41 42 43 44 45 46 47 |
# File 'lib/daytona_toolbox_api_client/models/pty_session_info.rb', line 36 def self.attribute_map { :'active' => :'active', :'cols' => :'cols', :'created_at' => :'createdAt', :'cwd' => :'cwd', :'envs' => :'envs', :'id' => :'id', :'lazy_start' => :'lazyStart', :'rows' => :'rows' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 |
# File 'lib/daytona_toolbox_api_client/models/pty_session_info.rb', line 311 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
74 75 76 77 |
# File 'lib/daytona_toolbox_api_client/models/pty_session_info.rb', line 74 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/daytona_toolbox_api_client/models/pty_session_info.rb', line 60 def self.openapi_types { :'active' => :'Boolean', :'cols' => :'Integer', :'created_at' => :'String', :'cwd' => :'String', :'envs' => :'Hash<String, String>', :'id' => :'String', :'lazy_start' => :'Boolean', :'rows' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
283 284 285 286 287 288 289 290 291 292 293 294 |
# File 'lib/daytona_toolbox_api_client/models/pty_session_info.rb', line 283 def ==(o) return true if self.equal?(o) self.class == o.class && active == o.active && cols == o.cols && created_at == o.created_at && cwd == o.cwd && envs == o.envs && id == o.id && lazy_start == o.lazy_start && rows == o.rows end |
#eql?(o) ⇒ Boolean
298 299 300 |
# File 'lib/daytona_toolbox_api_client/models/pty_session_info.rb', line 298 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
304 305 306 |
# File 'lib/daytona_toolbox_api_client/models/pty_session_info.rb', line 304 def hash [active, cols, created_at, cwd, envs, id, lazy_start, rows].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/daytona_toolbox_api_client/models/pty_session_info.rb', line 148 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @active.nil? invalid_properties.push('invalid value for "active", active cannot be nil.') end if @cols.nil? invalid_properties.push('invalid value for "cols", cols cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @cwd.nil? invalid_properties.push('invalid value for "cwd", cwd cannot be nil.') end if @envs.nil? invalid_properties.push('invalid value for "envs", envs cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @lazy_start.nil? invalid_properties.push('invalid value for "lazy_start", lazy_start cannot be nil.') end if @rows.nil? invalid_properties.push('invalid value for "rows", rows cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
333 334 335 336 337 338 339 340 341 342 343 344 345 |
# File 'lib/daytona_toolbox_api_client/models/pty_session_info.rb', line 333 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/daytona_toolbox_api_client/models/pty_session_info.rb', line 188 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @active.nil? return false if @cols.nil? return false if @created_at.nil? return false if @cwd.nil? return false if @envs.nil? return false if @id.nil? return false if @lazy_start.nil? return false if @rows.nil? true end |