Class: DaytonaToolboxApiClient::Recording
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- DaytonaToolboxApiClient::Recording
- Defined in:
- lib/daytona_toolbox_api_client/models/recording.rb
Instance Attribute Summary collapse
-
#duration_seconds ⇒ Object
Returns the value of attribute duration_seconds.
-
#end_time ⇒ Object
Returns the value of attribute end_time.
-
#file_name ⇒ Object
Returns the value of attribute file_name.
-
#file_path ⇒ Object
Returns the value of attribute file_path.
-
#id ⇒ Object
Returns the value of attribute id.
-
#size_bytes ⇒ Object
Returns the value of attribute size_bytes.
-
#start_time ⇒ Object
Returns the value of attribute start_time.
-
#status ⇒ Object
Returns the value of attribute status.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Recording
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Recording
Initializes the object
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/daytona_toolbox_api_client/models/recording.rb', line 80 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaToolboxApiClient::Recording` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaToolboxApiClient::Recording`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'duration_seconds') self.duration_seconds = attributes[:'duration_seconds'] end if attributes.key?(:'end_time') self.end_time = attributes[:'end_time'] end if attributes.key?(:'file_name') self.file_name = attributes[:'file_name'] else self.file_name = nil end if attributes.key?(:'file_path') self.file_path = attributes[:'file_path'] else self.file_path = nil end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'size_bytes') self.size_bytes = attributes[:'size_bytes'] end if attributes.key?(:'start_time') self.start_time = attributes[:'start_time'] else self.start_time = nil end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end end |
Instance Attribute Details
#duration_seconds ⇒ Object
Returns the value of attribute duration_seconds.
18 19 20 |
# File 'lib/daytona_toolbox_api_client/models/recording.rb', line 18 def duration_seconds @duration_seconds end |
#end_time ⇒ Object
Returns the value of attribute end_time.
20 21 22 |
# File 'lib/daytona_toolbox_api_client/models/recording.rb', line 20 def end_time @end_time end |
#file_name ⇒ Object
Returns the value of attribute file_name.
22 23 24 |
# File 'lib/daytona_toolbox_api_client/models/recording.rb', line 22 def file_name @file_name end |
#file_path ⇒ Object
Returns the value of attribute file_path.
24 25 26 |
# File 'lib/daytona_toolbox_api_client/models/recording.rb', line 24 def file_path @file_path end |
#id ⇒ Object
Returns the value of attribute id.
26 27 28 |
# File 'lib/daytona_toolbox_api_client/models/recording.rb', line 26 def id @id end |
#size_bytes ⇒ Object
Returns the value of attribute size_bytes.
28 29 30 |
# File 'lib/daytona_toolbox_api_client/models/recording.rb', line 28 def size_bytes @size_bytes end |
#start_time ⇒ Object
Returns the value of attribute start_time.
30 31 32 |
# File 'lib/daytona_toolbox_api_client/models/recording.rb', line 30 def start_time @start_time end |
#status ⇒ Object
Returns the value of attribute status.
32 33 34 |
# File 'lib/daytona_toolbox_api_client/models/recording.rb', line 32 def status @status end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
49 50 51 |
# File 'lib/daytona_toolbox_api_client/models/recording.rb', line 49 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
54 55 56 |
# File 'lib/daytona_toolbox_api_client/models/recording.rb', line 54 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 44 45 46 |
# File 'lib/daytona_toolbox_api_client/models/recording.rb', line 35 def self.attribute_map { :'duration_seconds' => :'durationSeconds', :'end_time' => :'endTime', :'file_name' => :'fileName', :'file_path' => :'filePath', :'id' => :'id', :'size_bytes' => :'sizeBytes', :'start_time' => :'startTime', :'status' => :'status' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/daytona_toolbox_api_client/models/recording.rb', line 257 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
73 74 75 76 |
# File 'lib/daytona_toolbox_api_client/models/recording.rb', line 73 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/daytona_toolbox_api_client/models/recording.rb', line 59 def self.openapi_types { :'duration_seconds' => :'Float', :'end_time' => :'String', :'file_name' => :'String', :'file_path' => :'String', :'id' => :'String', :'size_bytes' => :'Integer', :'start_time' => :'String', :'status' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
229 230 231 232 233 234 235 236 237 238 239 240 |
# File 'lib/daytona_toolbox_api_client/models/recording.rb', line 229 def ==(o) return true if self.equal?(o) self.class == o.class && duration_seconds == o.duration_seconds && end_time == o.end_time && file_name == o.file_name && file_path == o.file_path && id == o.id && size_bytes == o.size_bytes && start_time == o.start_time && status == o.status end |
#eql?(o) ⇒ Boolean
244 245 246 |
# File 'lib/daytona_toolbox_api_client/models/recording.rb', line 244 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
250 251 252 |
# File 'lib/daytona_toolbox_api_client/models/recording.rb', line 250 def hash [duration_seconds, end_time, file_name, file_path, id, size_bytes, start_time, status].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/daytona_toolbox_api_client/models/recording.rb', line 139 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @file_name.nil? invalid_properties.push('invalid value for "file_name", file_name cannot be nil.') end if @file_path.nil? invalid_properties.push('invalid value for "file_path", file_path cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @start_time.nil? invalid_properties.push('invalid value for "start_time", start_time cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'lib/daytona_toolbox_api_client/models/recording.rb', line 279 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
167 168 169 170 171 172 173 174 175 |
# File 'lib/daytona_toolbox_api_client/models/recording.rb', line 167 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @file_name.nil? return false if @file_path.nil? return false if @id.nil? return false if @start_time.nil? return false if @status.nil? true end |