Class: DaytonaToolboxApiClient::SystemMetrics

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/daytona_toolbox_api_client/models/system_metrics.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SystemMetrics

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/daytona_toolbox_api_client/models/system_metrics.rb', line 88

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaToolboxApiClient::SystemMetrics` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaToolboxApiClient::SystemMetrics`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'cpu_count')
    self.cpu_count = attributes[:'cpu_count']
  end

  if attributes.key?(:'cpu_used_pct')
    self.cpu_used_pct = attributes[:'cpu_used_pct']
  end

  if attributes.key?(:'disk_free')
    self.disk_free = attributes[:'disk_free']
  end

  if attributes.key?(:'disk_total')
    self.disk_total = attributes[:'disk_total']
  end

  if attributes.key?(:'disk_used')
    self.disk_used = attributes[:'disk_used']
  end

  if attributes.key?(:'mem_cache')
    self.mem_cache = attributes[:'mem_cache']
  end

  if attributes.key?(:'mem_total')
    self.mem_total = attributes[:'mem_total']
  end

  if attributes.key?(:'mem_used')
    self.mem_used = attributes[:'mem_used']
  end

  if attributes.key?(:'timestamp')
    self.timestamp = attributes[:'timestamp']
  end

  if attributes.key?(:'timestamp_unix')
    self.timestamp_unix = attributes[:'timestamp_unix']
  end
end

Instance Attribute Details

#cpu_countObject

Returns the value of attribute cpu_count.



18
19
20
# File 'lib/daytona_toolbox_api_client/models/system_metrics.rb', line 18

def cpu_count
  @cpu_count
end

#cpu_used_pctObject

Returns the value of attribute cpu_used_pct.



20
21
22
# File 'lib/daytona_toolbox_api_client/models/system_metrics.rb', line 20

def cpu_used_pct
  @cpu_used_pct
end

#disk_freeObject

Returns the value of attribute disk_free.



22
23
24
# File 'lib/daytona_toolbox_api_client/models/system_metrics.rb', line 22

def disk_free
  @disk_free
end

#disk_totalObject

Returns the value of attribute disk_total.



24
25
26
# File 'lib/daytona_toolbox_api_client/models/system_metrics.rb', line 24

def disk_total
  @disk_total
end

#disk_usedObject

Returns the value of attribute disk_used.



26
27
28
# File 'lib/daytona_toolbox_api_client/models/system_metrics.rb', line 26

def disk_used
  @disk_used
end

#mem_cacheObject

Returns the value of attribute mem_cache.



28
29
30
# File 'lib/daytona_toolbox_api_client/models/system_metrics.rb', line 28

def mem_cache
  @mem_cache
end

#mem_totalObject

Returns the value of attribute mem_total.



30
31
32
# File 'lib/daytona_toolbox_api_client/models/system_metrics.rb', line 30

def mem_total
  @mem_total
end

#mem_usedObject

Returns the value of attribute mem_used.



32
33
34
# File 'lib/daytona_toolbox_api_client/models/system_metrics.rb', line 32

def mem_used
  @mem_used
end

#timestampObject

Returns the value of attribute timestamp.



34
35
36
# File 'lib/daytona_toolbox_api_client/models/system_metrics.rb', line 34

def timestamp
  @timestamp
end

#timestamp_unixObject

Returns the value of attribute timestamp_unix.



36
37
38
# File 'lib/daytona_toolbox_api_client/models/system_metrics.rb', line 36

def timestamp_unix
  @timestamp_unix
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



55
56
57
# File 'lib/daytona_toolbox_api_client/models/system_metrics.rb', line 55

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



60
61
62
# File 'lib/daytona_toolbox_api_client/models/system_metrics.rb', line 60

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



39
40
41
42
43
44
45
46
47
48
49
50
51
52
# File 'lib/daytona_toolbox_api_client/models/system_metrics.rb', line 39

def self.attribute_map
  {
    :'cpu_count' => :'cpuCount',
    :'cpu_used_pct' => :'cpuUsedPct',
    :'disk_free' => :'diskFree',
    :'disk_total' => :'diskTotal',
    :'disk_used' => :'diskUsed',
    :'mem_cache' => :'memCache',
    :'mem_total' => :'memTotal',
    :'mem_used' => :'memUsed',
    :'timestamp' => :'timestamp',
    :'timestamp_unix' => :'timestampUnix'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/daytona_toolbox_api_client/models/system_metrics.rb', line 190

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



81
82
83
84
# File 'lib/daytona_toolbox_api_client/models/system_metrics.rb', line 81

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/daytona_toolbox_api_client/models/system_metrics.rb', line 65

def self.openapi_types
  {
    :'cpu_count' => :'Integer',
    :'cpu_used_pct' => :'Float',
    :'disk_free' => :'Integer',
    :'disk_total' => :'Integer',
    :'disk_used' => :'Integer',
    :'mem_cache' => :'Integer',
    :'mem_total' => :'Integer',
    :'mem_used' => :'Integer',
    :'timestamp' => :'String',
    :'timestamp_unix' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



160
161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'lib/daytona_toolbox_api_client/models/system_metrics.rb', line 160

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      cpu_count == o.cpu_count &&
      cpu_used_pct == o.cpu_used_pct &&
      disk_free == o.disk_free &&
      disk_total == o.disk_total &&
      disk_used == o.disk_used &&
      mem_cache == o.mem_cache &&
      mem_total == o.mem_total &&
      mem_used == o.mem_used &&
      timestamp == o.timestamp &&
      timestamp_unix == o.timestamp_unix
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


177
178
179
# File 'lib/daytona_toolbox_api_client/models/system_metrics.rb', line 177

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



183
184
185
# File 'lib/daytona_toolbox_api_client/models/system_metrics.rb', line 183

def hash
  [cpu_count, cpu_used_pct, disk_free, disk_total, disk_used, mem_cache, mem_total, mem_used, timestamp, timestamp_unix].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



145
146
147
148
149
# File 'lib/daytona_toolbox_api_client/models/system_metrics.rb', line 145

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/daytona_toolbox_api_client/models/system_metrics.rb', line 212

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



153
154
155
156
# File 'lib/daytona_toolbox_api_client/models/system_metrics.rb', line 153

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end