Class: DaytonaToolboxApiClient::FileInfo

Inherits:
ApiModelBase show all
Defined in:
lib/daytona_toolbox_api_client/models/file_info.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ FileInfo

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/daytona_toolbox_api_client/models/file_info.rb', line 85

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `DaytonaToolboxApiClient::FileInfo` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `DaytonaToolboxApiClient::FileInfo`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'group')
    self.group = attributes[:'group']
  else
    self.group = nil
  end

  if attributes.key?(:'is_dir')
    self.is_dir = attributes[:'is_dir']
  else
    self.is_dir = nil
  end

  if attributes.key?(:'mod_time')
    self.mod_time = attributes[:'mod_time']
  else
    self.mod_time = nil
  end

  if attributes.key?(:'mode')
    self.mode = attributes[:'mode']
  else
    self.mode = nil
  end

  if attributes.key?(:'modified_at')
    self.modified_at = attributes[:'modified_at']
  else
    self.modified_at = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'owner')
    self.owner = attributes[:'owner']
  else
    self.owner = nil
  end

  if attributes.key?(:'permissions')
    self.permissions = attributes[:'permissions']
  else
    self.permissions = nil
  end

  if attributes.key?(:'size')
    self.size = attributes[:'size']
  else
    self.size = nil
  end
end

Instance Attribute Details

#groupObject

Returns the value of attribute group.



18
19
20
# File 'lib/daytona_toolbox_api_client/models/file_info.rb', line 18

def group
  @group
end

#is_dirObject

Returns the value of attribute is_dir.



20
21
22
# File 'lib/daytona_toolbox_api_client/models/file_info.rb', line 20

def is_dir
  @is_dir
end

#mod_timeObject

Deprecated: ModTime uses Go’s time.String() layout which is not a standard format. Use ModifiedAt instead, which is serialized as ISO 8601 / RFC 3339.



23
24
25
# File 'lib/daytona_toolbox_api_client/models/file_info.rb', line 23

def mod_time
  @mod_time
end

#modeObject

Returns the value of attribute mode.



25
26
27
# File 'lib/daytona_toolbox_api_client/models/file_info.rb', line 25

def mode
  @mode
end

#modified_atObject

Returns the value of attribute modified_at.



27
28
29
# File 'lib/daytona_toolbox_api_client/models/file_info.rb', line 27

def modified_at
  @modified_at
end

#nameObject

Returns the value of attribute name.



29
30
31
# File 'lib/daytona_toolbox_api_client/models/file_info.rb', line 29

def name
  @name
end

#ownerObject

Returns the value of attribute owner.



31
32
33
# File 'lib/daytona_toolbox_api_client/models/file_info.rb', line 31

def owner
  @owner
end

#permissionsObject

Returns the value of attribute permissions.



33
34
35
# File 'lib/daytona_toolbox_api_client/models/file_info.rb', line 33

def permissions
  @permissions
end

#sizeObject

Returns the value of attribute size.



35
36
37
# File 'lib/daytona_toolbox_api_client/models/file_info.rb', line 35

def size
  @size
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



53
54
55
# File 'lib/daytona_toolbox_api_client/models/file_info.rb', line 53

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



58
59
60
# File 'lib/daytona_toolbox_api_client/models/file_info.rb', line 58

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



38
39
40
41
42
43
44
45
46
47
48
49
50
# File 'lib/daytona_toolbox_api_client/models/file_info.rb', line 38

def self.attribute_map
  {
    :'group' => :'group',
    :'is_dir' => :'isDir',
    :'mod_time' => :'modTime',
    :'mode' => :'mode',
    :'modified_at' => :'modifiedAt',
    :'name' => :'name',
    :'owner' => :'owner',
    :'permissions' => :'permissions',
    :'size' => :'size'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
# File 'lib/daytona_toolbox_api_client/models/file_info.rb', line 335

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



78
79
80
81
# File 'lib/daytona_toolbox_api_client/models/file_info.rb', line 78

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/daytona_toolbox_api_client/models/file_info.rb', line 63

def self.openapi_types
  {
    :'group' => :'String',
    :'is_dir' => :'Boolean',
    :'mod_time' => :'String',
    :'mode' => :'String',
    :'modified_at' => :'String',
    :'name' => :'String',
    :'owner' => :'String',
    :'permissions' => :'String',
    :'size' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



306
307
308
309
310
311
312
313
314
315
316
317
318
# File 'lib/daytona_toolbox_api_client/models/file_info.rb', line 306

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      group == o.group &&
      is_dir == o.is_dir &&
      mod_time == o.mod_time &&
      mode == o.mode &&
      modified_at == o.modified_at &&
      name == o.name &&
      owner == o.owner &&
      permissions == o.permissions &&
      size == o.size
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


322
323
324
# File 'lib/daytona_toolbox_api_client/models/file_info.rb', line 322

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



328
329
330
# File 'lib/daytona_toolbox_api_client/models/file_info.rb', line 328

def hash
  [group, is_dir, mod_time, mode, modified_at, name, owner, permissions, size].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/daytona_toolbox_api_client/models/file_info.rb', line 156

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @group.nil?
    invalid_properties.push('invalid value for "group", group cannot be nil.')
  end

  if @is_dir.nil?
    invalid_properties.push('invalid value for "is_dir", is_dir cannot be nil.')
  end

  if @mod_time.nil?
    invalid_properties.push('invalid value for "mod_time", mod_time cannot be nil.')
  end

  if @mode.nil?
    invalid_properties.push('invalid value for "mode", mode cannot be nil.')
  end

  if @modified_at.nil?
    invalid_properties.push('invalid value for "modified_at", modified_at cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @owner.nil?
    invalid_properties.push('invalid value for "owner", owner cannot be nil.')
  end

  if @permissions.nil?
    invalid_properties.push('invalid value for "permissions", permissions cannot be nil.')
  end

  if @size.nil?
    invalid_properties.push('invalid value for "size", size cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



357
358
359
360
361
362
363
364
365
366
367
368
369
# File 'lib/daytona_toolbox_api_client/models/file_info.rb', line 357

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



200
201
202
203
204
205
206
207
208
209
210
211
212
# File 'lib/daytona_toolbox_api_client/models/file_info.rb', line 200

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @group.nil?
  return false if @is_dir.nil?
  return false if @mod_time.nil?
  return false if @mode.nil?
  return false if @modified_at.nil?
  return false if @name.nil?
  return false if @owner.nil?
  return false if @permissions.nil?
  return false if @size.nil?
  true
end