Class: DaytonaToolboxApiClient::GitApi

Inherits:
Object
  • Object
show all
Defined in:
lib/daytona_toolbox_api_client/api/git_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ GitApi

Returns a new instance of GitApi.



19
20
21
# File 'lib/daytona_toolbox_api_client/api/git_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/daytona_toolbox_api_client/api/git_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#add_files(request, opts = {}) ⇒ nil

Add files to Git staging Add files to the Git staging area

Parameters:

  • request (GitAddRequest)

    Add files request

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


27
28
29
30
# File 'lib/daytona_toolbox_api_client/api/git_api.rb', line 27

def add_files(request, opts = {})
  add_files_with_http_info(request, opts)
  nil
end

#add_files_with_http_info(request, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Add files to Git staging Add files to the Git staging area

Parameters:

  • request (GitAddRequest)

    Add files request

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/daytona_toolbox_api_client/api/git_api.rb', line 37

def add_files_with_http_info(request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: GitApi.add_files ...'
  end
  # verify the required parameter 'request' is set
  if @api_client.config.client_side_validation && request.nil?
    fail ArgumentError, "Missing the required parameter 'request' when calling GitApi.add_files"
  end
  # resource path
  local_var_path = '/git/add'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(request)

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"GitApi.add_files",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: GitApi#add_files\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#checkout_branch(request, opts = {}) ⇒ nil

Checkout branch or commit Switch to a different branch or commit in the Git repository

Parameters:

  • request (GitCheckoutRequest)

    Checkout request

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


93
94
95
96
# File 'lib/daytona_toolbox_api_client/api/git_api.rb', line 93

def checkout_branch(request, opts = {})
  checkout_branch_with_http_info(request, opts)
  nil
end

#checkout_branch_with_http_info(request, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Checkout branch or commit Switch to a different branch or commit in the Git repository

Parameters:

  • request (GitCheckoutRequest)

    Checkout request

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/daytona_toolbox_api_client/api/git_api.rb', line 103

def checkout_branch_with_http_info(request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: GitApi.checkout_branch ...'
  end
  # verify the required parameter 'request' is set
  if @api_client.config.client_side_validation && request.nil?
    fail ArgumentError, "Missing the required parameter 'request' when calling GitApi.checkout_branch"
  end
  # resource path
  local_var_path = '/git/checkout'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(request)

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"GitApi.checkout_branch",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: GitApi#checkout_branch\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#clone_repository(request, opts = {}) ⇒ nil

Clone a Git repository Clone a Git repository to the specified path

Parameters:

  • request (GitCloneRequest)

    Clone repository request

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


159
160
161
162
# File 'lib/daytona_toolbox_api_client/api/git_api.rb', line 159

def clone_repository(request, opts = {})
  clone_repository_with_http_info(request, opts)
  nil
end

#clone_repository_with_http_info(request, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Clone a Git repository Clone a Git repository to the specified path

Parameters:

  • request (GitCloneRequest)

    Clone repository request

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/daytona_toolbox_api_client/api/git_api.rb', line 169

def clone_repository_with_http_info(request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: GitApi.clone_repository ...'
  end
  # verify the required parameter 'request' is set
  if @api_client.config.client_side_validation && request.nil?
    fail ArgumentError, "Missing the required parameter 'request' when calling GitApi.clone_repository"
  end
  # resource path
  local_var_path = '/git/clone'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(request)

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"GitApi.clone_repository",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: GitApi#clone_repository\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#commit_changes(request, opts = {}) ⇒ GitCommitResponse

Commit changes Commit staged changes to the Git repository

Parameters:

  • request (GitCommitRequest)

    Commit request

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



225
226
227
228
# File 'lib/daytona_toolbox_api_client/api/git_api.rb', line 225

def commit_changes(request, opts = {})
  data, _status_code, _headers = commit_changes_with_http_info(request, opts)
  data
end

#commit_changes_with_http_info(request, opts = {}) ⇒ Array<(GitCommitResponse, Integer, Hash)>

Commit changes Commit staged changes to the Git repository

Parameters:

  • request (GitCommitRequest)

    Commit request

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(GitCommitResponse, Integer, Hash)>)

    GitCommitResponse data, response status code and response headers



235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
# File 'lib/daytona_toolbox_api_client/api/git_api.rb', line 235

def commit_changes_with_http_info(request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: GitApi.commit_changes ...'
  end
  # verify the required parameter 'request' is set
  if @api_client.config.client_side_validation && request.nil?
    fail ArgumentError, "Missing the required parameter 'request' when calling GitApi.commit_changes"
  end
  # resource path
  local_var_path = '/git/commit'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(request)

  # return_type
  return_type = opts[:debug_return_type] || 'GitCommitResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"GitApi.commit_changes",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: GitApi#commit_changes\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#create_branch(request, opts = {}) ⇒ nil

Create a new branch Create a new branch in the Git repository

Parameters:

  • request (GitBranchRequest)

    Create branch request

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


293
294
295
296
# File 'lib/daytona_toolbox_api_client/api/git_api.rb', line 293

def create_branch(request, opts = {})
  create_branch_with_http_info(request, opts)
  nil
end

#create_branch_with_http_info(request, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Create a new branch Create a new branch in the Git repository

Parameters:

  • request (GitBranchRequest)

    Create branch request

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
# File 'lib/daytona_toolbox_api_client/api/git_api.rb', line 303

def create_branch_with_http_info(request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: GitApi.create_branch ...'
  end
  # verify the required parameter 'request' is set
  if @api_client.config.client_side_validation && request.nil?
    fail ArgumentError, "Missing the required parameter 'request' when calling GitApi.create_branch"
  end
  # resource path
  local_var_path = '/git/branches'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(request)

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"GitApi.create_branch",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: GitApi#create_branch\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#delete_branch(request, opts = {}) ⇒ nil

Delete a branch Delete a branch from the Git repository

Parameters:

Returns:

  • (nil)


359
360
361
362
# File 'lib/daytona_toolbox_api_client/api/git_api.rb', line 359

def delete_branch(request, opts = {})
  delete_branch_with_http_info(request, opts)
  nil
end

#delete_branch_with_http_info(request, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Delete a branch Delete a branch from the Git repository

Parameters:

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
# File 'lib/daytona_toolbox_api_client/api/git_api.rb', line 369

def delete_branch_with_http_info(request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: GitApi.delete_branch ...'
  end
  # verify the required parameter 'request' is set
  if @api_client.config.client_side_validation && request.nil?
    fail ArgumentError, "Missing the required parameter 'request' when calling GitApi.delete_branch"
  end
  # resource path
  local_var_path = '/git/branches'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(request)

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"GitApi.delete_branch",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: GitApi#delete_branch\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_commit_history(path, opts = {}) ⇒ Array<GitCommitInfo>

Get commit history Get the commit history of the Git repository

Parameters:

  • path (String)

    Repository path

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



425
426
427
428
# File 'lib/daytona_toolbox_api_client/api/git_api.rb', line 425

def get_commit_history(path, opts = {})
  data, _status_code, _headers = get_commit_history_with_http_info(path, opts)
  data
end

#get_commit_history_with_http_info(path, opts = {}) ⇒ Array<(Array<GitCommitInfo>, Integer, Hash)>

Get commit history Get the commit history of the Git repository

Parameters:

  • path (String)

    Repository path

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(Array<GitCommitInfo>, Integer, Hash)>)

    Array<GitCommitInfo> data, response status code and response headers



435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
# File 'lib/daytona_toolbox_api_client/api/git_api.rb', line 435

def get_commit_history_with_http_info(path, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: GitApi.get_commit_history ...'
  end
  # verify the required parameter 'path' is set
  if @api_client.config.client_side_validation && path.nil?
    fail ArgumentError, "Missing the required parameter 'path' when calling GitApi.get_commit_history"
  end
  # resource path
  local_var_path = '/git/history'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'path'] = path

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'Array<GitCommitInfo>'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"GitApi.get_commit_history",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: GitApi#get_commit_history\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_status(path, opts = {}) ⇒ GitStatus

Get Git status Get the Git status of the repository at the specified path

Parameters:

  • path (String)

    Repository path

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



489
490
491
492
# File 'lib/daytona_toolbox_api_client/api/git_api.rb', line 489

def get_status(path, opts = {})
  data, _status_code, _headers = get_status_with_http_info(path, opts)
  data
end

#get_status_with_http_info(path, opts = {}) ⇒ Array<(GitStatus, Integer, Hash)>

Get Git status Get the Git status of the repository at the specified path

Parameters:

  • path (String)

    Repository path

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(GitStatus, Integer, Hash)>)

    GitStatus data, response status code and response headers



499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
# File 'lib/daytona_toolbox_api_client/api/git_api.rb', line 499

def get_status_with_http_info(path, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: GitApi.get_status ...'
  end
  # verify the required parameter 'path' is set
  if @api_client.config.client_side_validation && path.nil?
    fail ArgumentError, "Missing the required parameter 'path' when calling GitApi.get_status"
  end
  # resource path
  local_var_path = '/git/status'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'path'] = path

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'GitStatus'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"GitApi.get_status",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: GitApi#get_status\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_branches(path, opts = {}) ⇒ ListBranchResponse

List branches Get a list of all branches in the Git repository

Parameters:

  • path (String)

    Repository path

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



553
554
555
556
# File 'lib/daytona_toolbox_api_client/api/git_api.rb', line 553

def list_branches(path, opts = {})
  data, _status_code, _headers = list_branches_with_http_info(path, opts)
  data
end

#list_branches_with_http_info(path, opts = {}) ⇒ Array<(ListBranchResponse, Integer, Hash)>

List branches Get a list of all branches in the Git repository

Parameters:

  • path (String)

    Repository path

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(ListBranchResponse, Integer, Hash)>)

    ListBranchResponse data, response status code and response headers



563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
# File 'lib/daytona_toolbox_api_client/api/git_api.rb', line 563

def list_branches_with_http_info(path, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: GitApi.list_branches ...'
  end
  # verify the required parameter 'path' is set
  if @api_client.config.client_side_validation && path.nil?
    fail ArgumentError, "Missing the required parameter 'path' when calling GitApi.list_branches"
  end
  # resource path
  local_var_path = '/git/branches'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'path'] = path

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ListBranchResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"GitApi.list_branches",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: GitApi#list_branches\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#pull_changes(request, opts = {}) ⇒ nil

Pull changes from remote Pull changes from the remote Git repository

Parameters:

  • request (GitRepoRequest)

    Pull request

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


617
618
619
620
# File 'lib/daytona_toolbox_api_client/api/git_api.rb', line 617

def pull_changes(request, opts = {})
  pull_changes_with_http_info(request, opts)
  nil
end

#pull_changes_with_http_info(request, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Pull changes from remote Pull changes from the remote Git repository

Parameters:

  • request (GitRepoRequest)

    Pull request

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
# File 'lib/daytona_toolbox_api_client/api/git_api.rb', line 627

def pull_changes_with_http_info(request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: GitApi.pull_changes ...'
  end
  # verify the required parameter 'request' is set
  if @api_client.config.client_side_validation && request.nil?
    fail ArgumentError, "Missing the required parameter 'request' when calling GitApi.pull_changes"
  end
  # resource path
  local_var_path = '/git/pull'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(request)

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"GitApi.pull_changes",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: GitApi#pull_changes\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#push_changes(request, opts = {}) ⇒ nil

Push changes to remote Push local changes to the remote Git repository

Parameters:

  • request (GitRepoRequest)

    Push request

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


683
684
685
686
# File 'lib/daytona_toolbox_api_client/api/git_api.rb', line 683

def push_changes(request, opts = {})
  push_changes_with_http_info(request, opts)
  nil
end

#push_changes_with_http_info(request, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Push changes to remote Push local changes to the remote Git repository

Parameters:

  • request (GitRepoRequest)

    Push request

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
# File 'lib/daytona_toolbox_api_client/api/git_api.rb', line 693

def push_changes_with_http_info(request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: GitApi.push_changes ...'
  end
  # verify the required parameter 'request' is set
  if @api_client.config.client_side_validation && request.nil?
    fail ArgumentError, "Missing the required parameter 'request' when calling GitApi.push_changes"
  end
  # resource path
  local_var_path = '/git/push'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(request)

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || []

  new_options = opts.merge(
    :operation => :"GitApi.push_changes",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: GitApi#push_changes\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end