Class: DaytonaToolboxApiClient::InterpreterApi
- Inherits:
-
Object
- Object
- DaytonaToolboxApiClient::InterpreterApi
- Defined in:
- lib/daytona_toolbox_api_client/api/interpreter_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_interpreter_context(request, opts = {}) ⇒ InterpreterContext
Create a new interpreter context Creates a new isolated interpreter context with optional working directory and language.
-
#create_interpreter_context_with_http_info(request, opts = {}) ⇒ Array<(InterpreterContext, Integer, Hash)>
Create a new interpreter context Creates a new isolated interpreter context with optional working directory and language.
-
#delete_interpreter_context(id, opts = {}) ⇒ Hash<String, String>
Delete an interpreter context Deletes an interpreter context and shuts down its worker process.
-
#delete_interpreter_context_with_http_info(id, opts = {}) ⇒ Array<(Hash<String, String>, Integer, Hash)>
Delete an interpreter context Deletes an interpreter context and shuts down its worker process.
-
#execute_interpreter_code(opts = {}) ⇒ nil
Execute code in an interpreter context Executes code in a specified context (or default context if not specified) via WebSocket streaming.
-
#execute_interpreter_code_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Execute code in an interpreter context Executes code in a specified context (or default context if not specified) via WebSocket streaming.
-
#initialize(api_client = ApiClient.default) ⇒ InterpreterApi
constructor
A new instance of InterpreterApi.
-
#list_interpreter_contexts(opts = {}) ⇒ ListContextsResponse
List all user-created interpreter contexts Returns information about all user-created interpreter contexts (excludes default context).
-
#list_interpreter_contexts_with_http_info(opts = {}) ⇒ Array<(ListContextsResponse, Integer, Hash)>
List all user-created interpreter contexts Returns information about all user-created interpreter contexts (excludes default context).
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ InterpreterApi
Returns a new instance of InterpreterApi.
19 20 21 |
# File 'lib/daytona_toolbox_api_client/api/interpreter_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/daytona_toolbox_api_client/api/interpreter_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create_interpreter_context(request, opts = {}) ⇒ InterpreterContext
Create a new interpreter context Creates a new isolated interpreter context with optional working directory and language
27 28 29 30 |
# File 'lib/daytona_toolbox_api_client/api/interpreter_api.rb', line 27 def create_interpreter_context(request, opts = {}) data, _status_code, _headers = create_interpreter_context_with_http_info(request, opts) data end |
#create_interpreter_context_with_http_info(request, opts = {}) ⇒ Array<(InterpreterContext, Integer, Hash)>
Create a new interpreter context Creates a new isolated interpreter context with optional working directory and language
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/daytona_toolbox_api_client/api/interpreter_api.rb', line 37 def create_interpreter_context_with_http_info(request, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: InterpreterApi.create_interpreter_context ...' end # verify the required parameter 'request' is set if @api_client.config.client_side_validation && request.nil? fail ArgumentError, "Missing the required parameter 'request' when calling InterpreterApi.create_interpreter_context" end # resource path local_var_path = '/process/interpreter/context' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(request) # return_type return_type = opts[:debug_return_type] || 'InterpreterContext' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"InterpreterApi.create_interpreter_context", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: InterpreterApi#create_interpreter_context\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_interpreter_context(id, opts = {}) ⇒ Hash<String, String>
Delete an interpreter context Deletes an interpreter context and shuts down its worker process
95 96 97 98 |
# File 'lib/daytona_toolbox_api_client/api/interpreter_api.rb', line 95 def delete_interpreter_context(id, opts = {}) data, _status_code, _headers = delete_interpreter_context_with_http_info(id, opts) data end |
#delete_interpreter_context_with_http_info(id, opts = {}) ⇒ Array<(Hash<String, String>, Integer, Hash)>
Delete an interpreter context Deletes an interpreter context and shuts down its worker process
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/daytona_toolbox_api_client/api/interpreter_api.rb', line 105 def delete_interpreter_context_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: InterpreterApi.delete_interpreter_context ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling InterpreterApi.delete_interpreter_context" end # resource path local_var_path = '/process/interpreter/context/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Hash<String, String>' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"InterpreterApi.delete_interpreter_context", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: InterpreterApi#delete_interpreter_context\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#execute_interpreter_code(opts = {}) ⇒ nil
Execute code in an interpreter context Executes code in a specified context (or default context if not specified) via WebSocket streaming
157 158 159 160 |
# File 'lib/daytona_toolbox_api_client/api/interpreter_api.rb', line 157 def execute_interpreter_code(opts = {}) execute_interpreter_code_with_http_info(opts) nil end |
#execute_interpreter_code_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Execute code in an interpreter context Executes code in a specified context (or default context if not specified) via WebSocket streaming
166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/daytona_toolbox_api_client/api/interpreter_api.rb', line 166 def execute_interpreter_code_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: InterpreterApi.execute_interpreter_code ...' end # resource path local_var_path = '/process/interpreter/execute' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"InterpreterApi.execute_interpreter_code", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: InterpreterApi#execute_interpreter_code\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#list_interpreter_contexts(opts = {}) ⇒ ListContextsResponse
List all user-created interpreter contexts Returns information about all user-created interpreter contexts (excludes default context)
214 215 216 217 |
# File 'lib/daytona_toolbox_api_client/api/interpreter_api.rb', line 214 def list_interpreter_contexts(opts = {}) data, _status_code, _headers = list_interpreter_contexts_with_http_info(opts) data end |
#list_interpreter_contexts_with_http_info(opts = {}) ⇒ Array<(ListContextsResponse, Integer, Hash)>
List all user-created interpreter contexts Returns information about all user-created interpreter contexts (excludes default context)
223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 |
# File 'lib/daytona_toolbox_api_client/api/interpreter_api.rb', line 223 def list_interpreter_contexts_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: InterpreterApi.list_interpreter_contexts ...' end # resource path local_var_path = '/process/interpreter/context' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ListContextsResponse' # auth_names auth_names = opts[:debug_auth_names] || [] = opts.merge( :operation => :"InterpreterApi.list_interpreter_contexts", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: InterpreterApi#list_interpreter_contexts\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |